@@ -1,7 +1,9 @@
 # neuralmagic: no copyright
 # flake8: noqa
+# fmt: off
+# isort: skip_file
 __all__ = ["__version__", "version", "version_major", "version_minor", "version_bug", "version_build", "version_major_minor", "optimized", "is_release", "revision", "splash", "is_nightly", "build_date"]
-__version__ = '1.3.2'
+__version__ = "1.4.0"
 
 version = __version__
 version_major, version_minor, version_bug, version_build = version.split(".") + (
@@ -12,6 +14,6 @@ optimized = 1
 is_release = 1
 is_nightly = 0
 is_enterprise = 1
-revision = '783530f7'
-splash = 'DeepSparse, Copyright 2021-present / Neuralmagic, Inc. version: 1.3.2 (783530f7) (release) (optimized) (system=avx2, binary=avx2)'
-build_date = '20230116'
+revision = "3be6be5f"
+splash = "DeepSparse, Copyright 2021-present / Neuralmagic, Inc. version: 1.4.0 (3be6be5f) (release) (optimized) (system=avx512, binary=avx512)"
+build_date = "20230207"
