@@ -28,7 +28,13 @@ from pydantic import BaseModel, Field
 from deepsparse import Context, Engine, MultiModelEngine, Scheduler
 from deepsparse.benchmark import ORTEngine
 from deepsparse.cpu import cpu_details
-from deepsparse.loggers import BaseLogger, MetricCategories, validate_identifier
+from deepsparse.loggers import (
+    REQUEST_DETAILS_IDENTIFIER_PREFIX,
+    RESOURCE_UTILIZATION_IDENTIFIER_PREFIX,
+    BaseLogger,
+    MetricCategories,
+    validate_identifier,
+)
 from deepsparse.tasks import SupportedTasks, dynamic_import_task
 from deepsparse.timing import InferencePhases, Timer
 
@@ -187,7 +193,13 @@ class Pipeline(ABC):
 
         self._batch_size = self._batch_size or 1
 
-    def __call__(self, *args, monitoring: bool = False, **kwargs) -> BaseModel:
+        self.log(
+            identifier=f"{RESOURCE_UTILIZATION_IDENTIFIER_PREFIX}/num_cores",
+            value=num_cores,
+            category=MetricCategories.SYSTEM,
+        )
+
+    def __call__(self, *args, **kwargs) -> BaseModel:
         if "engine_inputs" in kwargs:
             raise ValueError(
                 "invalid kwarg engine_inputs. engine inputs determined "
@@ -227,7 +239,9 @@ class Pipeline(ABC):
             category=MetricCategories.DATA,
         )
         self.log(
-            identifier=InferencePhases.PRE_PROCESS,
+            # note, will be replaced by a reference instead of "bare" string
+            # with the upcoming PR for system logging
+            identifier=f"prediction_latency/{InferencePhases.PRE_PROCESS}",
             value=timer.time_delta(InferencePhases.PRE_PROCESS),
             category=MetricCategories.SYSTEM,
         )
@@ -244,13 +258,23 @@ class Pipeline(ABC):
         engine_outputs = self.join_engine_outputs(batch_outputs)
         timer.stop(InferencePhases.ENGINE_FORWARD)
 
+        self.log(
+            identifier=f"{REQUEST_DETAILS_IDENTIFIER_PREFIX}/input_batch_size",
+            # to get the batch size of the inputs, we need to look
+            # to multiply the engine batch size (self._batch_size)
+            # by the number of batches processed by the engine during
+            # a single inference call
+            value=len(batch_outputs) * self._batch_size,
+            category=MetricCategories.SYSTEM,
+        )
+
         self.log(
             identifier="engine_outputs",
             value=engine_outputs,
             category=MetricCategories.DATA,
         )
         self.log(
-            identifier=InferencePhases.ENGINE_FORWARD,
+            identifier=f"prediction_latency/{InferencePhases.ENGINE_FORWARD}",
             value=timer.time_delta(InferencePhases.ENGINE_FORWARD),
             category=MetricCategories.SYSTEM,
         )
@@ -274,12 +298,12 @@ class Pipeline(ABC):
             category=MetricCategories.DATA,
         )
         self.log(
-            identifier=InferencePhases.POST_PROCESS,
+            identifier=f"prediction_latency/{InferencePhases.POST_PROCESS}",
             value=timer.time_delta(InferencePhases.POST_PROCESS),
             category=MetricCategories.SYSTEM,
         )
         self.log(
-            identifier=InferencePhases.TOTAL_INFERENCE,
+            identifier=f"prediction_latency/{InferencePhases.TOTAL_INFERENCE}",
             value=timer.time_delta(InferencePhases.TOTAL_INFERENCE),
             category=MetricCategories.SYSTEM,
         )
@@ -700,22 +724,32 @@ class Pipeline(ABC):
             kwargs=kwargs,
         )
 
-    def log(self, identifier: str, value: Any, category: str):
+    def log(
+        self,
+        identifier: str,
+        value: Any,
+        category: str,
+    ):
         """
-        Pass the logged data to the DeepSparse logger object (if present)
+        Pass the logged data to the DeepSparse logger object (if present).
 
         :param identifier: The string name assigned to the logged value
         :param value: The logged data structure
         :param category: The metric category that the log belongs to
         """
-        identifier = f"{self.alias or self.task}/{identifier}"
+        if not self.logger:
+            return
+
+        if not hasattr(self, "task"):
+            self.task = None
+
+        identifier = f"{self.alias or self.task or 'unknown_pipeline'}/{identifier}"
         validate_identifier(identifier)
-        if self.logger:
-            self.logger.log(
-                identifier=identifier,
-                value=value,
-                category=category,
-            )
+        self.logger.log(
+            identifier=identifier,
+            value=value,
+            category=category,
+        )
         return
 
     def parse_inputs(self, *args, **kwargs) -> BaseModel:
